@@ -19,17 +19,14 @@ import Test.Sandwich.Formatters.FailureReport
 import Test.Sandwich.Formatters.MarkdownSummary
 import Test.Sandwich.Formatters.Print.Types
 import Test.Sandwich.Formatters.Silent
+import Test.Sandwich.Formatters.TerminalUI
+import Test.Sandwich.Formatters.TerminalUI.Types
 import Test.Sandwich.Internal.Running
 import Test.Sandwich.Options
 import Test.Sandwich.Types.ArgParsing
 import Test.Sandwich.Types.RunTree
 import Test.Sandwich.Types.Spec
 
-#ifndef mingw32_HOST_OS
-import Test.Sandwich.Formatters.TerminalUI
-import Test.Sandwich.Formatters.TerminalUI.Types
-#endif
-
 #if MIN_VERSION_time(1,9,0)
 import Data.Time.Format.ISO8601
 formatTime = T.unpack . T.replace ":" "_" . T.pack . iso8601Show
@@ -115,9 +112,7 @@ formatter :: Parser FormatterType
 formatter =
   flag' Print (long "print" <> help "Print to stdout")
   <|> flag' PrintFailures (long "print-failures" <> help "Print failures only to stdout")
-#ifndef mingw32_HOST_OS
   <|> flag' TUI (long "tui" <> help "Open terminal UI app")
-#endif
   <|> flag' Silent (long "silent" <> help "Run silently (print the run root only)")
   <|> flag Auto Auto (long "auto" <> help "Automatically decide which formatter to use")
 
@@ -235,29 +230,32 @@ addOptionsFromArgs baseOptions (CommandLineOptions {..}) = do
   let failureReportFormatter = SomeFormatter $ defaultFailureReportFormatter { failureReportLogLevel = optLogLevel }
   let silentFormatter = SomeFormatter defaultSilentFormatter
 
-  maybeMainFormatter <- case (optRepeatCount, optFormatter) of
-    (x, _) | x /= 1 -> return $ Just printFormatter
-    (_, Auto) ->
-      -- Formerly this tried to use the TUI formatter by default after checking isTuiFormatterSupported.
-      -- Unfortunately, this function returns true under "cabal test", which also redirects stdout. So
-      -- you end up with no output and a hanging process (until you hit 'q'; stdin is still attached).
-      -- Seems like the best default is just the print formatter.
-      return $ Just printFormatter
-#ifndef mingw32_HOST_OS
-    (_, TUI) -> do
-      let mainTerminalUiFormatter = headMay [x | SomeFormatter (cast -> Just x@(TerminalUIFormatter {})) <- optionsFormatters baseOptions]
-      return $ Just $ SomeFormatter $ (fromMaybe defaultTerminalUIFormatter mainTerminalUiFormatter) { terminalUILogLevel = optLogLevel }
-#endif
-    (_, Print) -> return $ Just printFormatter
-    (_, PrintFailures) -> return $ Just failureReportFormatter
-    (_, Silent) -> return $ Just silentFormatter
+  let mainFormatter = case (optRepeatCount, optFormatter) of
+        (x, _) | x /= 1 -> case optFormatter of
+                   TUI -> printFormatter
+                   PrintFailures -> failureReportFormatter
+                   Silent -> silentFormatter
+                   Print -> printFormatter
+                   Auto -> printFormatter
+        (_, Auto) ->
+          -- Formerly this tried to use the TUI formatter by default after checking isTuiFormatterSupported.
+          -- Unfortunately, this function returns true under "cabal test", which also redirects stdout. So
+          -- you end up with no output and a hanging process (until you hit 'q'; stdin is still attached).
+          -- Seems like the best default is just the print formatter.
+          printFormatter
+        (_, TUI) ->
+          let mainTerminalUiFormatter = headMay [x | SomeFormatter (cast -> Just x@(TerminalUIFormatter {})) <- optionsFormatters baseOptions]
+          in SomeFormatter $ (fromMaybe defaultTerminalUIFormatter mainTerminalUiFormatter) { terminalUILogLevel = optLogLevel }
+        (_, Print) -> printFormatter
+        (_, PrintFailures) -> failureReportFormatter
+        (_, Silent) -> silentFormatter
 
   -- Strip out any "main" formatters since the options control that
   let baseFormatters = optionsFormatters baseOptions
                      & tryAddMarkdownSummaryFormatter optMarkdownSummaryPath
                      & filter (not . isMainFormatter)
 
-  let finalFormatters = baseFormatters <> catMaybes [maybeMainFormatter]
+  let finalFormatters = baseFormatters <> [mainFormatter]
                       & fmap (setVisibilityThreshold optVisibilityThreshold)
 
   let options = baseOptions {
@@ -280,27 +278,18 @@ addOptionsFromArgs baseOptions (CommandLineOptions {..}) = do
     isMainFormatter :: SomeFormatter -> Bool
     isMainFormatter (SomeFormatter x) = case cast x of
       Just (_ :: PrintFormatter) -> True
-#ifdef mingw32_HOST_OS
-      Nothing -> False
-#else
       Nothing -> case cast x of
         Just (_ :: TerminalUIFormatter) -> True
         Nothing -> False
-#endif
 
     setVisibilityThreshold Nothing x = x
     setVisibilityThreshold (Just v) x@(SomeFormatter f) = case cast f of
       Just pf@(PrintFormatter {}) -> SomeFormatter (pf { printFormatterVisibilityThreshold = v })
       Nothing -> case cast f of
-#ifdef mingw32_HOST_OS
-        Just (frf :: FailureReportFormatter) -> SomeFormatter (frf { failureReportVisibilityThreshold = v })
-        Nothing -> x
-#else
         Just tuif@(TerminalUIFormatter {}) -> SomeFormatter (tuif { terminalUIVisibilityThreshold = v })
         Nothing -> case cast f of
           Just (frf :: FailureReportFormatter) -> SomeFormatter (frf { failureReportVisibilityThreshold = v })
           Nothing -> x
-#endif
 
     isMarkdownSummaryFormatter :: SomeFormatter -> Bool
     isMarkdownSummaryFormatter (SomeFormatter x) = case cast x of
